.. :authors:

Authors:
    - `Richard 'Dr. Frankenstein' Booth (University of Cambridge) <https://github.com/rbooth200>`_
    - `Jeff 'The Monster' Jennings (University of Cambridge) <https://github.com/jeffjennings>`_
    - `Marco 'It's Alive!!!' Tazzari (University of Cambridge) <https://github.com/mtazzari>`_
